@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0002';
+our $VERSION = '0.0003';
 
 use Moo;
 use strictures 2;
@@ -115,7 +115,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0002
+version 0.0003
 
 =head1 SYNOPSIS
 
@@ -165,14 +165,17 @@ Show progress.
 
 =head1 METHODS
 
-=for Pod::Coverage BUILD
-
 =head2 new
 
-  $synth = Synth::Config->new(%args);
+  $synth = Synth::Config->new(model => $model);
 
 Create a new C<Synth::Config> object.
 
+This automatically makes an SQLite database with a table named for the
+given B<model>.
+
+=for Pod::Coverage BUILD
+
 =head2 make_setting
 
   my $id = $synth->make_setting(%args);
@@ -187,14 +190,18 @@ Example:
 
 =head2 recall_setting
 
-  my $setting = $synth->recall_setting(%args);
+  my $setting = $synth->recall_setting(id => $id);
 
-Return the parameters of a setting.
+Return the parameters of a setting for the given B<id>.
 
 =head1 SEE ALSO
 
 L<Moo>
 
+L<Mojo::JSON>
+
+L<Mojo::SQLite>
+
 Knob: L<https://codepen.io/jhnsnc/pen/KXYayG>
 
 Switch: L<https://codepen.io/magnus16/pen/grzqMz>
